==> libquvi-scripts-0.4.1p0.tgz: share/libquvi-scripts/lua/website/sapo.lua <==

-- libquvi-scripts v0.4.1
-- Copyright (C) 2010  Toni Gundogdu <legatvs@gmail.com>
--
-- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
--
-- This library is free software; you can redistribute it and/or
-- modify it under the terms of the GNU Lesser General Public
-- License as published by the Free Software Foundation; either
-- version 2.1 of the License, or (at your option) any later version.
--
-- This library is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public
-- License along with this library; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-- 02110-1301  USA
--

-- Identify the script.
function ident (self)
    package.path = self.script_dir .. '/?.lua'
    local C      = require 'quvi/const'
    local r      = {}
    r.domain     = "videos%.sapo%.pt"
    r.formats    = "default"
    r.categories = C.proto_http
    -- TODO: Replace with LUA equivalent to Perl's "\w{20}".
    local p      = "/"
    for i=1,20 do p = p.."%w" end
    p = p .. "$"
    local U      = require 'quvi/util'
    r.handles    = U.handles(self.page_url, {r.domain}, {p})
    return r
end

-- Query available formats.
function query_formats(self)
    self.formats = 'default'
    return self
end

-- Parse media URL.
function parse (self)

    self.host_id = "sapo"
    local page   = quvi.fetch (self.page_url)

    if (page:find ('rtmp:%/%/')) then
        error ("media requires rtmp which we do not currently support")
    end

    local _,_,s = page:find ('class="tit">(.-)</div>')
    if (s == nil) then
        _,_,s = page:find ('<title>(.-)%s+-%s+')
    end
    self.title = s or error ("no match: media title")

    local _,_,s = page:find ('?file=(.-)/mov')
    if (s == nil) then error ("no match: media url") end
    self.url = {s .. "/mov"}

    local _,_,s = self.url[1]:find ('.*/(.-)/mov')
    self.id     = s or error ("no match: media id")

    return self
end

-- vim: set ts=4 sw=4 tw=72 expandtab:

==> libquvi-scripts-0.4.10.tgz: share/libquvi-scripts/lua/website/sapo.lua <==

-- libquvi-scripts v0.4.10
-- Copyright (C) 2010-2012  Toni Gundogdu <legatvs@gmail.com>
--
-- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
--
-- This library is free software; you can redistribute it and/or
-- modify it under the terms of the GNU Lesser General Public
-- License as published by the Free Software Foundation; either
-- version 2.1 of the License, or (at your option) any later version.
--
-- This library is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public
-- License along with this library; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-- 02110-1301  USA
--

-- Identify the script.
function ident(self)
    package.path = self.script_dir .. '/?.lua'
    local C      = require 'quvi/const'
    local r      = {}
    r.domain     = "videos%.sapo%.pt"
    r.formats    = "default"
    r.categories = C.proto_http
    local U      = require 'quvi/util'
    r.handles    = U.handles(self.page_url, {r.domain})
    return r
end

-- Query available formats.
function query_formats(self)
    self.formats = 'default'
    return self
end

-- Parse media URL.
function parse (self)
    self.host_id = "sapo"

    self.id = self.page_url:match('http://.*sapo.pt/([^?"/]+)')
                or error("no match: media ID")

    local p = quvi.fetch(self.page_url)

    self.thumbnail_url = p:match('"og:image" content="(.-)"') or ''

    self.title = p:match('"og:title" content="(.-)%s+%-%s+SAPO')
                  or error("no match: media title")

    self.url = {p:match('videoVerifyMrec%("(.-)"')
                or error("no match: media URL")}

    return self
end

-- vim: set ts=4 sw=4 tw=72 expandtab:
